StateSnapshot<T> class

Represents a snapshot of state at a specific point in time.

Constructors

StateSnapshot(T value, {required DateTime timestamp, Map<String, dynamic> metadata = const {}})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
metadata Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final
value → T
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override