StateSerializationException class
Exception thrown when state serialization operations fail.
This includes errors during JSON encoding/decoding, type conversion, or other serialization-related operations.
- Inheritance
-
- Object
- StateException
- StateSerializationException
Constructors
-
StateSerializationException(String message, {Map<
String, dynamic> context = const {}, Object? cause, StackTrace? stackTrace, Type? targetType, Object? failedValue}) -
const
Properties
- cause → Object?
-
The original exception that caused this error, if any.
finalinherited
-
context
→ Map<
String, dynamic> -
Additional context information about the error.
finalinherited
- failedValue → Object?
-
The value that caused the serialization failure.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
The error message describing what went wrong.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
The stack trace where this exception occurred.
finalinherited
- targetType → Type?
-
The type that failed to serialize/deserialize.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited