StateSnapshot<T> class
Represents a snapshot of state at a specific point in time.
Constructors
-
StateSnapshot(T value, {required DateTime timestamp, Map<
String, dynamic> metadata = const {}}) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override